Crate merde_msgpack

Crate merde_msgpack 

license: MIT/Apache-2.0 crates.io docs.rs

merde_rmp

The merde logo: a glorious poop floating above a pair of hands

Logo by MisiasArt

Adds RMP serialization/deserialization support for merde.

You would normally add a dependency on merde directly, enabling its rmp feature.

Structs

MsgpackDeserializer
A MessagePack deserializer, that implements merde_core::Deserializer.

Functions

from_slice
Deserialize an instance of type T from a byte slice of MessagePack data.
from_slice_owned
Deserialize an instance of type T from a byte slice of MessagePack data, and return its static variant e.g. (CowStr<’static>, etc.)